summaryrefslogtreecommitdiffstats
path: root/sys/scsi
diff options
context:
space:
mode:
authordes <des@FreeBSD.org>1998-04-27 11:36:06 +0000
committerdes <des@FreeBSD.org>1998-04-27 11:36:06 +0000
commit1e8b395cf1615195ef035dd1b2c59e5f565345da (patch)
treea41671d30c35e005a215510ace2fce2186b296b6 /sys/scsi
parent1c811baafb24bd03555fb376d826af31717a198d (diff)
downloadFreeBSD-src-1e8b395cf1615195ef035dd1b2c59e5f565345da.zip
FreeBSD-src-1e8b395cf1615195ef035dd1b2c59e5f565345da.tar.gz
Fixed spelling of "fictitious" in diagnostics and comments
PR: kern/6429
Diffstat (limited to 'sys/scsi')
-rw-r--r--sys/scsi/cd.c4
-rw-r--r--sys/scsi/od.c16
-rw-r--r--sys/scsi/sd.c6
3 files changed, 13 insertions, 13 deletions
diff --git a/sys/scsi/cd.c b/sys/scsi/cd.c
index 5e80335..cd08d10 100644
--- a/sys/scsi/cd.c
+++ b/sys/scsi/cd.c
@@ -14,7 +14,7 @@
*
* Ported to run under 386BSD by Julian Elischer (julian@tfs.com) Sept 1992
*
- * $Id: cd.c,v 1.90 1998/04/15 17:47:17 bde Exp $
+ * $Id: cd.c,v 1.91 1998/04/17 22:37:06 des Exp $
*/
#include "opt_bounce.h"
@@ -1086,7 +1086,7 @@ cd_getdisklabel(unit)
* make partition 0 the whole disk
*/
strncpy(cd->disklabel.d_typename, "scsi cd_rom", 16);
- strncpy(cd->disklabel.d_packname, "ficticious", 16);
+ strncpy(cd->disklabel.d_packname, "fictitious", 16);
cd->disklabel.d_secsize = cd->params.blksize; /* as long as it's not 0 */
cd->disklabel.d_nsectors = 100;
cd->disklabel.d_ntracks = 1;
diff --git a/sys/scsi/od.c b/sys/scsi/od.c
index 51b94cf..f91d29b 100644
--- a/sys/scsi/od.c
+++ b/sys/scsi/od.c
@@ -28,7 +28,7 @@
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*
- * $Id: od.c,v 1.36 1998/04/15 17:47:18 bde Exp $
+ * $Id: od.c,v 1.37 1998/04/17 22:37:07 des Exp $
*/
/*
@@ -97,7 +97,7 @@ struct scsi_data {
#define ODINIT 0x04 /* device has been init'd */
struct disk_parms {
u_char heads; /* Number of heads */
- u_int16_t cyls; /* Number of cylinders (ficticous) */
+ u_int16_t cyls; /* Number of cylinders (fictitious) */
u_int16_t sectors; /* Number of sectors/track */
u_int16_t secsiz; /* Number of bytes/sector */
u_int32_t disksize; /* total number sectors */
@@ -780,7 +780,7 @@ od_size(unit, flags)
NULL,
flags | SCSI_SILENT | SCSI_DATA_IN) != 0) {
- /* default to a ficticous geometry */
+ /* default to a fictitious geometry */
od->params.heads = 64;
} else {
SC_DEBUG(sc_link, SDEV_DB3,
@@ -791,7 +791,7 @@ od_size(unit, flags)
od->params.heads = scsi_sense.pages.rigid_geometry.nheads;
if (od->params.heads == 0)
- od->params.heads = 64; /* ficticous */
+ od->params.heads = 64; /* fictitious */
od->params.rpm =
scsi_2btou(&scsi_sense.pages.rigid_geometry.medium_rot_rate_1);
}
@@ -817,7 +817,7 @@ od_size(unit, flags)
NULL,
flags | SCSI_SILENT | SCSI_DATA_IN) != 0) {
- /* default to a ficticous geometry */
+ /* default to a fictitious geometry */
od->params.sectors = 32;
} else {
SC_DEBUG(sc_link, SDEV_DB3,
@@ -827,7 +827,7 @@ od_size(unit, flags)
od->params.sectors =
scsi_2btou(&scsi_sense.pages.disk_format.ph_sec_t_1);
if (od->params.sectors == 0)
- od->params.sectors = 32; /* ficticous */
+ od->params.sectors = 32; /* fictitious */
}
return od->params.disksize;
@@ -887,12 +887,12 @@ od_get_parms(unit, flags)
return 0;
/*
- * Use ficticious geometry, this depends on the size of medium.
+ * Use fictitious geometry, this depends on the size of medium.
*/
sectors = od_size(unit, flags);
/* od_size() sets secsiz, disksize, sectors, and heads */
- /* ficticous number of cylinders, so that C*H*S <= total */
+ /* fictitious number of cylinders, so that C*H*S <= total */
if (disk_parms->sectors != 0 && disk_parms->heads != 0) {
disk_parms->cyls =
sectors / (disk_parms->sectors * disk_parms->heads);
diff --git a/sys/scsi/sd.c b/sys/scsi/sd.c
index 7b168cc..b1c642c 100644
--- a/sys/scsi/sd.c
+++ b/sys/scsi/sd.c
@@ -14,7 +14,7 @@
*
* Ported to run under 386BSD by Julian Elischer (julian@dialix.oz.au) Sept 1992
*
- * $Id: sd.c,v 1.124 1998/04/19 23:32:36 julian Exp $
+ * $Id: sd.c,v 1.125 1998/04/22 10:25:27 julian Exp $
*/
#include "opt_bounce.h"
@@ -907,9 +907,9 @@ sd_get_parms(int unit, int flags)
flags | SCSI_DATA_IN) != 0) {
printf("sd%d could not mode sense (4).", unit);
- printf(" Using ficticious geometry\n");
+ printf(" Using fictitious geometry\n");
/*
* use adaptec standard ficticious geometry
* this depends on which controller (e.g. 1542C is
* different. but we have to put SOMETHING here..)
*/
@@ -907,9 +907,9 @@ sd_get_parms(int unit, int flags)
/*
- * use adaptec standard ficticious geometry
+ * use adaptec standard fictitious geometry
* this depends on which controller (e.g. 1542C is
* different. but we have to put SOMETHING here..)
OpenPOWER on IntegriCloud